.. mdinclude:: ../README.md

Contents
========

.. toctree::
   :maxdepth: 2

   License <license>
   Authors <authors>
   Contributing <contributing>
   Module Reference <api/modules>
   Wiki <wiki/index>
   COVID19 Proposal <Grants/brown-covid19-grant-proposal>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

